import { Resource } from 'aws-cdk-lib';
import { FargateCluster, FargateClusterProps } from 'aws-cdk-lib/aws-eks';
import { ILogGroup, RetentionDays } from 'aws-cdk-lib/aws-logs';
import { ISecret } from 'aws-cdk-lib/aws-secretsmanager';
import { IParameter } from 'aws-cdk-lib/aws-ssm';
import { Construct } from 'constructs';
import { CloudWatchMonitoring } from '../k8s-aws/cloudwatch-monitoring';
import { ExternalDns } from '../k8s-aws/external-dns';
import { ExternalSecret } from '../k8s-aws/external-secret';
import { ExternalSecretsOperator, NamespacedExternalSecretOptions } from '../k8s-aws/external-secrets-operator';
import { FargateLogger } from '../k8s-aws/fargate-logger';
export interface CloudWatchMonitoringOptions {
    readonly enabled?: boolean;
}
export interface FargateLoggingOptions {
    /**
       * Controls whether logging will be set up for pods using the default
       * Fargate provide on the EKS cluster.
       *
       * @default true
       */
    readonly enabled?: boolean;
    /**
       * The CloudWatch log group where Farget container logs will be sent.
       */
    readonly logGroup?: ILogGroup;
    /**
        * The prefix to add to the start of log streams created by the Fargate
        * logger.
        */
    readonly logStreamPrefix?: string;
    /**
        * The number of days logs sent to CloudWatch from Fluent Bit should be
        * retained before they are automatically removed.
        */
    readonly retention?: RetentionDays;
}
export interface ExternalDnsOptions {
    readonly enabled?: boolean;
    readonly domainFilter?: string[];
}
export interface ExternalSecretsOptions {
    readonly enabled?: boolean;
    readonly createNamespace?: boolean;
    readonly name?: string;
    readonly namespace?: string;
}
export interface AwsIntegratedFargateClusterProps extends FargateClusterProps {
    readonly cloudWatchMonitoringOptions?: CloudWatchMonitoringOptions;
    readonly externalDnsOptions?: ExternalDnsOptions;
    readonly externalSecretsOptions?: ExternalSecretsOptions;
    readonly loggingOptions?: FargateLoggingOptions;
}
export declare class AwsIntegratedFargateCluster extends Resource {
    readonly cloudWatchMonitoring?: CloudWatchMonitoring;
    readonly externalDns?: ExternalDns;
    readonly externalSecrets?: ExternalSecretsOperator;
    readonly fargateLogger?: FargateLogger;
    readonly resource: FargateCluster;
    constructor(scope: Construct, id: string, props: AwsIntegratedFargateClusterProps);
    registerSecretsManagerSecret(id: string, secret: ISecret, options?: NamespacedExternalSecretOptions): ExternalSecret;
    registerSsmParameterSecret(id: string, parameter: IParameter, options?: NamespacedExternalSecretOptions): ExternalSecret;
}
