import { Resource, ResourceProps } from 'aws-cdk-lib';
import { Cluster, HelmChart } from 'aws-cdk-lib/aws-eks';
import { ISecret } from 'aws-cdk-lib/aws-secretsmanager';
import { IParameter } from 'aws-cdk-lib/aws-ssm';
import { Construct } from 'constructs';
import { ExternalSecret, SecretFieldReference } from './external-secret';
export interface ExternalSecretOptions {
    readonly fields?: SecretFieldReference[];
    readonly name?: string;
}
export interface NamespacedExternalSecretOptions extends ExternalSecretOptions {
    readonly namespace?: string;
}
/**
 * Configuration for the Inbound Resolver resource.
 */
export interface ExternalSecretsOperatorProps extends ResourceProps {
    readonly cluster: Cluster;
    readonly createNamespace?: boolean;
    readonly name?: string;
    readonly namespace?: string;
}
export declare class ExternalSecretsOperator extends Resource {
    static readonly DEFAULT_NAMESPACE: string;
    readonly cluster: Cluster;
    readonly createNamespace?: boolean;
    readonly name: string;
    readonly namespace: string;
    readonly helmChart: HelmChart;
    readonly operatorName: string;
    constructor(scope: Construct, id: string, props: ExternalSecretsOperatorProps);
    registerSecretsManagerSecret(id: string, secret: ISecret, options?: NamespacedExternalSecretOptions): ExternalSecret;
    registerSsmParameterSecret(id: string, parameter: IParameter, options?: NamespacedExternalSecretOptions): ExternalSecret;
}
